#
# spec file for package rshim
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019 Mellanox Technologies. All Rights Reserved.
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rshim
Version:        2.3.8
Release:        1.1
Summary:        User-space driver for Mellanox BlueField SoC
License:        BSD-3-Clause OR GPL-2.0-only
Group:          System/Management
URL:            https://github.com/mellanox/rshim-user-space
Source0:        https://github.com/Mellanox/rshim-user-space/archive/refs/tags/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(libusb-1.0)
ExcludeArch:    %{ix86} armv6l armv6hl armv7l armv7hl

%description
This is the user-space driver to access the BlueField SoC via the rshim
interface. It provides ways to push boot stream, debug the target or login
via the virtual console or network interface.

%prep
%autosetup -p1 -n rshim-user-space-rshim-%{version}

%build
./bootstrap.sh
%configure \
	--docdir=%{_docdir}/%{name} \
	--with-systemdsystemunitdir=%{_unitdir} \
	--enable-usb \
	--enable-pcie \
	--enable-fuse \
	%{nil}
%make_build

%install
%make_install

%pre
%service_add_pre rshim.service

%post
%service_add_post rshim.service

%preun
%service_del_preun rshim.service

%postun
%service_del_postun rshim.service

%files
%license LICENSE
%doc README.md
%config(noreplace) %{_sysconfdir}/rshim.conf
%{_sbindir}/bf-reg
%{_sbindir}/bfb-install
%{_sbindir}/bfb-tool
%{_sbindir}/fwpkg_unpack.py
%{_sbindir}/mlx-mkbfb
%{_sbindir}/rshim
%{_unitdir}/rshim.service
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man8/*.8%{?ext_man}

%changelog
* Wed May 14 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.3.8:
  * Fix a potentially unintialized variable
- includes changes from 2.3.7:
  * bfb-install: Reactivate NIC_FW for runtime upgrade
- includes changes from 2.3.6:
  * bfb-install: cleanup the TMP_DIR
- includes changes from 2.3.5:
  * bfb-install: add validation of bfb and rshim options
  * Fix the rshim command line for register read/write
- includes changes from 2.3.4:
  * mlx-mkbfb: Improve the performance when extracting a single image
  * Reduce CPU utilization by network optimization
- includes changes from 2.3.2:
  * bfb-install: Support trimmed NIC_FW
  * bfdump support
  * Use BREADCRUMB.BIT32 to indicate NIC mode
  * Added bfb-tool script
- includes changes from 2.3.1:
  * Enhance command line for register read/write
  * Support PCIe device name runtime update
  * bfb-install: Enhancement for runtime upgrade
  * bfb-install: don't exit script when rshim install fails
  * Add fwpkg_unpack tool
  * Added mlx-mkbfb
- build with fuse 3 (boo#1243151)
* Thu Feb  6 2025 Matthias Brugger <mbrugger@suse.com>
- Update to 2.2.4.0
  * Update default USB timeout
  * Add BF_MODE misc output to show DPU or NIC mode (BF3 only)
  * Allow 0 to restrore USB_TIMEOUT default value
  * Allow multi rshim processes for dev attchment
  * Force stop if stuck during systemd service stop
  * removes unnecesary POLLOUT polling in USB
* Wed Nov 13 2024 Matthias Brugger <mbrugger@suse.com>
- Update to 2.1.6.0
  * Add USB_TIMEOUT to rshim misc and conf settings
  * Use BOOT_RESET_SKIP command to simulate eMMC boot
* Fri Oct 25 2024 Matthias Brugger <mbrugger@suse.com>
- Update to 2.1.5.0
  * Avoid polling blocked status during reset
  * Adjust default reset delay to 3 seconds on PCIe
  * Remove workaround support for BF2 A0 chip
  * Only poll/check locked mode for PCIe backend
  * support register read/write via /dev/rshim0/rshim for pcie_lf on BF3
  * add 'CLEAR_ON_READ' command to delete rshim log after read
  * Add ownership transfer feature
  * Allow /dev/rshim<N> devfs creation only with --force option enabled
  * Make sending the initial force command a one-time event
  * Add VFIO support for Bluefield-3 on PCIe
  * Add support for command mode
  * Adjust default boot timeout to 300s
  * Make rshim run in single instance
* Fri May 10 2024 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.29.1 (jsc#PED-6843 jsc#PED-6979)
  * Output SECURE_NIC_MODE in /dev/rshim<N>/misc
  * Allow remote installation via bfb-install
  * Make DROP_MODE more robust
  * Avoid race in bfb push when accessing from BMC and rshim tool in parallel
  * Fix handshake between NIC F and rshim over PCIe
* Thu Mar  7 2024 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.20.0 (jsc#PED-6843 jsc#PED-6979)
  * Adjust delay time for nic_fw reset
  * Add BFB completion condition for enhanced NIC mode
  * Fixes for potential high CPU utilization
* Thu Nov  2 2023 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.12.1
  * Display uptime in seconds for BF3
  * Add fuse3 support
* Wed Aug 30 2023 Matthias Brugger <mbrugger@suse.com>
- Update to 2.0.9
  * Fix fallback logic of direct mapping
  * Make timeout configurable through /dev/rshimX/misc
* Fri Apr 21 2023 Matthias Brugger <mbrugger@suse.com>
- Update service to new tag format
- update to 2.0.7
  * adjust reset delay
  * avoid leak the file descriptor for /dev/uio
* Thu Mar 16 2023 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.19.2
  * fix potential NULL pointer access during USB disconnection
  * fix vfio and direct mapping mode with several devices
  * avoid use of stale cached pci_dev pointer after device reset
  * adjust reset delay
  * update to dual-licensese GPL-2.0/BSD-3-Clause
* Thu Sep 15 2022 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.13.7
  * make use of rshim with several devices more efficient
  * support 32 bit CR space possible on BF3 USB access
  * support more transfer sizes
  * add new device ID for BF3
  * allow to en/disable VFIO/UIO support via rshim.conf
  * make restart of rshim process more robust fixing potential race
  * set default boot timeout to 150 seconds
* Thu Jul 14 2022 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.11.5
  * Fix a possible crash on PCIe for BF1/2
  * Fix possible race condition when several rshim devices are present
  * Fix a kernel crash when undbinding from uio
  * Detect new USB/rshim hot plug
* Fri Nov 19 2021 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.2.2
  * bfb-install: Handle new indications for installation completion
  * Make USB reset configurable and set to 3 seconds
  * Move USB reset to USB up event
* Wed Sep 29 2021 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.6.1.5
  * Disable the background timer if no rshim devices
  * Setting default path for rshim config file
  * Refine when some workarounds should be applied
  * Fix hypervisor crash when several cards boot or push streams
  * Set MTU to standard max size
* Thu Mar 11 2021 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.5.10
  * fix possible tmfifo data loss in PCIe interface
  * fix USB deadlock
  * reduce CPU load when no rshim device present
  * add PCIe hotplug support
* Mon Jan 25 2021 Matthias Brugger <mbrugger@suse.com>
- fix _service file
- update to 2.0.5.8.3
  * fix various issues
  * add workaround for Bluefield-2 REV-0
* Thu Nov 19 2020 Matthias Brugger <mbrugger@suse.com>
- update to 2.0.55.1
  * add bfb-install script
- fix version number naming
- add versioning to _service file
* Wed Nov 11 2020 Matthias Brugger <mbrugger@suse.com>
- update to latest version (jsc#SLE-16098 jsc#SLE-13565 jsc#SLE-16108 jsc#SLE-15271)
  * Some robust fixes for USB rshim
  * Fix a typo in pcie mmap
  * Check rshim accessibility when re-enabling it
  * Enable console output during boot stream pushing
  * Add some delay for the pcie_lf probe
  * Auto-start rshim service after installation
* Thu Oct  1 2020 Matthias Brugger <mbrugger@suse.com>
- update to latest version
  * enable BlueField-2 support
  * Add configuration file support
* Wed Jun 10 2020 Matthias Brugger <mbrugger@suse.com>
- add _service file
- update to latest version
* Mon Apr 27 2020 Matthias Brugger <mbrugger@suse.com>
- add version 2.0.4
